@@ -3,6 +3,13 @@ methods::setOldClass(c("ip_network", "vctrs_vctr"))
 
 #' Vector of IP networks
 #'
+#' @description
+#' `ip_network()` constructs a vector of IP networks.
+#'
+#' `is_ip_network()` checks if an object is of class `ip_network`.
+#'
+#' `as_ip_network()` casts an object to `ip_network`.
+#'
 #' @details
 #' An IP network corresponds to a contiguous range of IP addresses
 #' (also known as an IP block). CIDR notation represents an
@@ -30,26 +37,19 @@ methods::setOldClass(c("ip_network", "vctrs_vctr"))
 #'
 #' @seealso [prefix_length()], [network_address()], [netmask()], [hostmask()]
 #'
-#' @param x An `ip_network` vector
-#' @param ... Arguments to be passed to other methods
-#'
-#' @name ip_network
-NULL
-
-
-# Construction ------------------------------------------------------------
-
-#' `ip_network()`
-#'
-#' `ip_network()` constructs a vector of IP networks.
-#'
-#' @param ip Character vector of IP networks, in CIDR notation (IPv4 or IPv6).
+#' @param ... Included for S3 generic consistency
+#' @param x
+#' * For `ip_network()`: A character vector of IP networks, in CIDR notation
+#'   (IPv4 or IPv6)
+#' * For `is_ip_network()`: An object to test
+#' * For `as_ip_network()`: An object to cast
+#' * For `as.character()`: An `ip_network` vector
 #' @param address An [`ip_address`] vector
 #' @param prefix_length An integer vector
 #' @param strict If `TRUE` (the default) and the input has host bits set,
 #'   then a warning is emitted and `NA` is returned. If `FALSE`, the
 #'   host bits are set to zero and a valid IP network is returned. If you need
-#'   to retain the host bits, consider using `ip_interface()` instead.
+#'   to retain the host bits, consider using [ip_interface()] instead.
 #' @return An S3 vector of class `ip_network`
 #'
 #' @examples
@@ -67,6 +67,12 @@ NULL
 #'
 #' # but we can mask the host bits if desired
 #' ip_network("192.168.0.1/22", strict = FALSE)
+#' @name ip_network
+NULL
+
+
+# Construction ------------------------------------------------------------
+
 #' @rdname ip_network
 #' @export
 ip_network <- function(...) {
@@ -75,12 +81,12 @@ ip_network <- function(...) {
 
 #' @rdname ip_network
 #' @export
-ip_network.default <- function(ip = character(), strict = TRUE, ...) {
+ip_network.default <- function(x = character(), strict = TRUE, ...) {
   if (!is_bool(strict)) {
     abort("'strict' be must TRUE or FALSE")
   }
 
-  wrap_parse_network(ip, strict)
+  wrap_parse_network(x, strict)
 }
 
 #' @rdname ip_network
@@ -118,29 +124,34 @@ new_ip_network <- function(address1 = integer(), address2 = integer(), address3
   ), class = "ip_network")
 }
 
-#' `as_ip_network()`
-#'
-#' `as_ip_network()` casts an object to `ip_network`.
-#'
-#' @rdname ip_network
-#' @export
-as_ip_network <- function(x) vec_cast(x, ip_network())
-
-#' `is_ip_network()`
-#'
-#' `is_ip_network()` checks if an object is of class `ip_network`.
-#'
 #' @rdname ip_network
 #' @export
 is_ip_network <- function(x) inherits(x, "ip_network")
 
-#' @rdname ip_network
-#' @export
-format.ip_network <- function(x, ...) as.character(x)
+
+# Casting ------------------------------------------------------------
 
 #' @rdname ip_network
 #' @export
-as.character.ip_network <- function(x, ...) vec_cast(x, character())
+as_ip_network <- function(x) UseMethod("as_ip_network")
+
+#' @rdname ip_network
+#' @export
+as_ip_network.character <- function(x) ip_network(x)
+
+#' @rdname ip_network
+#' @export
+as_ip_network.ip_interface <- function(x) {
+  ip_network(x, field(x, "prefix"), strict = FALSE)
+}
+
+#' @rdname ip_network
+#' @export
+as.character.ip_network <- function(x, ...) wrap_print_network(x)
+
+#' @rdname ip_network
+#' @export
+format.ip_network <- function(x, ...) as.character(x)
 
 
 # Comparison ------------------------------------------------------------
